@@ -1,5 +1,8 @@
+from functools import wraps
+
 def lazyproperty(fn):
     @property
+    @wraps(fn)
     def _lazyproperty(self):
         attr = "_" + fn.__name__
         if not hasattr(self, attr):
