@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
+from __future__ import absolute_import, print_function
 from . import _osx as osx
 from . import _tty as tty
 from .exceptions import (
@@ -8,8 +8,8 @@ from .exceptions import (
 )
 from ._lib import lazyproperty
 from ._sh import (
-    Brew, Defaults, spawn, collapseuser, commonpath, curl, mkdir_p, read_json,
-    write_json, modify_json, isdirname
+    Brew, Defaults, spawn, collapseuser, commonpath, curl, mkdir_p,
+    read_config, write_config, modify_config, isdirname, prompt
 )
 from fnmatch import fnmatch
 from glob import iglob
@@ -23,7 +23,6 @@ import platform
 import re
 import shutil
 import subprocess
-import sys
 
 _DEFAULTS_TRUE_RE = re.compile(r"\b(Y(ES)?|TRUE)\b", re.I)
 _DEFAULTS_FALSE_RE = re.compile(r"\b(N(O)?|FALSE)\b", re.I)
@@ -48,11 +47,17 @@ class Cider(object):
 
     @lazyproperty
     def bootstrap_file(self):
-        return os.path.join(self.cider_dir, "bootstrap.json")
+        legacy_path = os.path.join(self.cider_dir, "bootstrap.json")
+        if os.path.isfile(legacy_path):
+            return legacy_path
+        return os.path.join(self.cider_dir, "bootstrap.yaml")
 
     @lazyproperty
     def defaults_file(self):
-        return os.path.join(self.cider_dir, "defaults.json")
+        legacy_path = os.path.join(self.cider_dir, "defaults.json")
+        if os.path.isfile(legacy_path):
+            return legacy_path
+        return os.path.join(self.cider_dir, "defaults.yaml")
 
     @lazyproperty
     def env(self):
@@ -82,10 +87,10 @@ class Cider(object):
         return os.path.join(self.support_dir, "symlink_targets.json")
 
     def read_bootstrap(self):
-        return read_json(self.bootstrap_file, {})
+        return read_config(self.bootstrap_file, {})
 
     def read_defaults(self):
-        return read_json(self.defaults_file, {})
+        return read_config(self.defaults_file, {})
 
     def _check_cider_dir(self):
         if not os.path.isdir(self.cider_dir):
@@ -96,7 +101,7 @@ class Cider(object):
 
     def _modify_bootstrap(self, key, transform=None, fallback=None):
         if transform is None:
-            transform = lambda x: x
+            transform = lambda x: x  # pep8: noqa
 
         if fallback is None:
             fallback = []
@@ -108,7 +113,7 @@ class Cider(object):
             return bootstrap
 
         self._check_cider_dir()
-        return modify_json(self.bootstrap_file, outer_transform)
+        return modify_config(self.bootstrap_file, outer_transform)
 
     def _modify_defaults(self, domain, transform):
         def outer_transform(defaults):
@@ -116,15 +121,15 @@ class Cider(object):
             return defaults
 
         self._check_cider_dir()
-        return modify_json(self.defaults_file, outer_transform)
+        return modify_config(self.defaults_file, outer_transform)
 
     def _cached_targets(self):
-        return read_json(self.symlink_targets_file, [])
+        return read_config(self.symlink_targets_file, [])
 
     def _update_target_cache(self, new_targets):
         self._check_cider_dir()
         mkdir_p(os.path.dirname(self.symlink_targets_file))
-        write_json(self.symlink_targets_file, sorted(new_targets))
+        write_config(self.symlink_targets_file, sorted(new_targets))
 
     def _remove_dead_targets(self, targets):
         for target in targets:
@@ -212,6 +217,8 @@ class Cider(object):
         for tap in bootstrap.get("taps", []):
             homebrew.tap(tap)
 
+        outdated = homebrew.outdated()
+
         for formula in bootstrap.get("formulas", []):
             if formula in dependencies:
                 deps = dependencies[formula]
@@ -231,7 +238,7 @@ class Cider(object):
                     caskbrew.safe_install(cask, ignore_errors)
                     del casks[casks.index(cask)]
 
-            homebrew.safe_install(formula, ignore_errors)
+            homebrew.safe_install(formula, ignore_errors, formula in outdated)
 
         for cask in casks:
             caskbrew.safe_install(cask, ignore_errors)
@@ -426,10 +433,21 @@ class Cider(object):
         return self.read_bootstrap().get("taps", [])
 
     def missing(self):
+        # The packages currently in the bootstrap file
         installed = [item.split()[0].strip() for item in self.installed()]
+        # List of packages installed on the system
         brewed = self.brew.ls()
 
         def brew_orphan(formula):
+            # Temporary workaround to avoid bug with brew-pip.
+            # https://github.com/msanders/cider/issues/25
+            if formula.startswith("pip-"):
+                return False
+            if self.cask:
+                # If the formula is not in bootstrap file
+                # return True so we can add the formula to the
+                # bootstrap file
+                return formula not in installed
             uses = self.brew.uses(formula)
             return len(set(installed) & set(uses)) == 0
 
@@ -451,14 +469,12 @@ class Cider(object):
         missing_items = self.missing()
         if missing_items:
             suffix = "s" if len(missing_items) != 1 else ""
-            fmt = "{0} missing formula{1} (tip: try `brew uses --installed` " + \
-                  "to see what's using it)"
+            fmt = "{0} missing formula{1} (tip: try `brew uses " + \
+                  "--installed` to see what's using it)"
             tty.puterr(fmt.format(len(missing_items), suffix), warning=True)
-
             print("\n".join(missing_items) + "\n")
-            sys.stdout.write("Add to bootstrap? [y/N] ")
 
-            if sys.stdin.read(1).lower() == "y":
+            if prompt("Add to bootstrap? [y/N] "):
                 self.add_to_bootstrap(missing_items)
         else:
             print("Everything up to date.")
@@ -469,11 +485,9 @@ class Cider(object):
             suffix = "s" if len(missing_taps) != 1 else ""
             fmt = "{0} missing tap{1}"
             tty.puterr(fmt.format(len(missing_taps), suffix), warning=True)
-
             print("\n".join(missing_taps) + "\n")
-            sys.stdout.write("Add to bootstrap? [y/N] ")
 
-            if sys.stdin.read(1).lower() == "y":
+            if prompt("Add to bootstrap? [y/N] "):
                 self.add_taps(missing_taps)
         else:
             print("Everything up to date.")
@@ -550,7 +564,7 @@ class Cider(object):
         osx.remove_icon(app_path)
 
     def apply_icons(self):
-        bootstrap = read_json(self.bootstrap_file)
+        bootstrap = read_config(self.bootstrap_file)
         icons = bootstrap.get("icons", {})
         for app, icon in icons.items():
             _apply_icon(app, icon)
@@ -657,11 +671,15 @@ def _apply_icon(app, icon):
 
     try:
         components = urlparse(icon)
-        tmpdir = mkdtemp()
-        icon_path = os.path.join(tmpdir, os.path.basename(components["path"]))
-        print(tty.progress("Downloading {0} icon: {1}".format(app, icon)))
-        curl(icon, icon_path)
+        if not components["scheme"] or components['scheme'] == "file":
+            icon_path = components["path"]
+        else:
+            tmpdir = mkdtemp()
+            icon_path = os.path.join(tmpdir,
+                                     os.path.basename(components["path"]))
+            print(tty.progress("Downloading {0} icon: {1}".format(app, icon)))
+            curl(icon, icon_path)
     except ValueError:
         icon_path = icon
 
-    osx.set_icon(app_path, icon_path)
+    osx.set_icon(app_path, os.path.expanduser(icon_path))
